@@ -12,6 +12,12 @@
 #include <CGAL/Cartesian.h>
 #include <CGAL/Regular_triangulation_3.h>
 #include <CGAL/Regular_triangulation_euclidean_traits_3.h>
+#define ALPHASHAPES
+#ifdef ALPHASHAPES
+	#include <CGAL/Alpha_shape_vertex_base_3.h>
+	#include <CGAL/Alpha_shape_cell_base_3.h>
+	#include <CGAL/Alpha_shape_3.h>
+#endif
 #include <CGAL/Triangulation_vertex_base_with_info_3.h>
 #include <CGAL/Triangulation_cell_base_with_info_3.h>
 #include <CGAL/Delaunay_triangulation_3.h>
@@ -50,7 +56,7 @@ class SimpleCellInfo : public Point {
 	// Care to initialize it if you need it, there is no magic numbering to rely on
 	unsigned int id;
 	Real s;
-	bool isFictious;
+	bool isFictious;//true if the cell has at least one fictious bounding sphere as a vertex
 	SimpleCellInfo (void) {isFictious=false; s=0;}
 	SimpleCellInfo& setPoint(const Point &p) { Point::operator= (p); return *this; }
 	SimpleCellInfo& setScalar(const Real &scalar) { s=scalar; return *this; }
@@ -92,11 +98,19 @@ typedef vertex_info								Vertex_Info;
 typedef cell_info								Cell_Info;
 typedef CGAL::Triangulation_vertex_base_with_info_3<Vertex_Info, Traits>	Vb_info;
 typedef CGAL::Triangulation_cell_base_with_info_3<Cell_Info, Traits>		Cb_info;
+#ifdef ALPHASHAPES
+typedef CGAL::Alpha_shape_vertex_base_3<Traits,Vb_info> Vb;
+typedef CGAL::Alpha_shape_cell_base_3<Traits,Cb_info>   Fb;
+typedef CGAL::Triangulation_data_structure_3<Vb, Fb>				Tds;
+#else
 typedef CGAL::Triangulation_data_structure_3<Vb_info, Cb_info>			Tds;
+#endif
 
 typedef CGAL::Triangulation_3<K>						Triangulation;
 typedef CGAL::Regular_triangulation_3<Traits, Tds>				RTriangulation;
-
+#ifdef ALPHASHAPES
+typedef CGAL::Alpha_shape_3<RTriangulation>  					AlphaShape;
+#endif
 typedef typename RTriangulation::Vertex_iterator                    		VertexIterator;
 typedef typename RTriangulation::Vertex_handle                      		VertexHandle;
 typedef typename RTriangulation::Finite_vertices_iterator                    	FiniteVerticesIterator;
