@@ -7,10 +7,10 @@
 *************************************************************************/
 #pragma once
 
-#include <yade/pkg/common/PeriodicEngines.hpp>
-#include <yade/pkg/common/Dispatching.hpp>
-#include <yade/pkg/common/Collider.hpp>
-#include <yade/core/Scene.hpp>
+#include <pkg/common/PeriodicEngines.hpp>
+#include <pkg/common/Dispatching.hpp>
+#include <pkg/common/Collider.hpp>
+#include <core/Scene.hpp>
 #include <vector>
 #include <string>
 
