@@ -4,8 +4,8 @@
 
 #pragma once
 
-#include<yade/pkg/common/Dispatching.hpp>
-#include<yade/pkg/common/Sphere.hpp>
+#include<pkg/common/Dispatching.hpp>
+#include<pkg/common/Sphere.hpp>
 
 class Ig2_Sphere_Sphere_ScGeom: public IGeomFunctor{
 	public:
