@@ -1,21 +1,26 @@
 // © 2013 Jan Elias, http://www.fce.vutbr.cz/STM/elias.j/, elias.j@fce.vutbr.cz
 // https://www.vutbr.cz/www_base/gigadisk.php?i=95194aa9a
 
-
 #pragma once
 
 #ifdef YADE_CGAL
 
-#include<core/Shape.hpp>
-#include<core/IGeom.hpp>
-#include<core/GlobalEngine.hpp>
-#include<core/Material.hpp>
-#include<pkg/common/Aabb.hpp>
-#include<pkg/common/Dispatching.hpp>
-#include<pkg/dem/FrictPhys.hpp>
-#include<pkg/common/Wall.hpp>
-#include<pkg/common/Facet.hpp>
-#include<lib/base/openmp-accu.hpp>
+// NDEBUG causes crashes in CGAL sometimes. Anton
+#ifdef NDEBUG
+	#undef NDEBUG
+#endif
+
+#include <core/Omega.hpp>
+#include <core/Shape.hpp>
+#include <core/Interaction.hpp>
+#include <core/Material.hpp>
+#include <pkg/dem/ScGeom.hpp>
+#include <pkg/dem/FrictPhys.hpp>
+#include <pkg/common/Wall.hpp>
+#include <pkg/common/Facet.hpp>
+#include <pkg/common/Sphere.hpp>
+#include <pkg/common/Dispatching.hpp>
+#include <pkg/common/ElastMat.hpp>
 
 #include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
 #include <CGAL/Delaunay_triangulation_3.h>
@@ -30,8 +35,6 @@
 #include <CGAL/AABB_triangle_primitive.h>
 #include <CGAL/squared_distance_3.h>
 
-#include<time.h>
-
 #define likely(x)       __builtin_expect((x),1)
 #define unlikely(x)     __builtin_expect((x),0)
 
@@ -62,14 +65,15 @@ class Polyhedra: public Shape{
 		Vector3r GetInertia(){Initialize(); return inertia;}
 		vector<int> GetSurfaceTriangulation(){Initialize(); return faceTri;}
 		vector<vector<int>> GetSurfaces() const;
-		void Initialize();		
+		void Initialize();
 		bool IsInitialized(){return init;}
 		std::vector<Vector3r> GetOriginalVertices();
 		Real GetVolume(){Initialize(); return volume;}
 		Quaternionr GetOri(){Initialize(); return orientation;}
 		Polyhedron GetPolyhedron(){return P;};
 		void Clear(){v.clear(); P.clear(); init = 0; size = Vector3r(1.,1.,1.); faceTri.clear();};
-		void setVertices(const std::vector<Vector3r>& v) { init=false; this->v=v; Initialize(); }
+		void setVertices(const std::vector<Vector3r>& v);
+		void setVertices4(const Vector3r& v0, const Vector3r& v1,const Vector3r& v2,const Vector3r& v3);
 
 	protected:	
 		//triangulation of facets for plotting
@@ -103,8 +107,9 @@ class Polyhedra: public Shape{
 			.def("GetCentroid",&Polyhedra::GetCentroid,"return polyhedra's centroid")
 			.def("GetSurfaceTriangulation",&Polyhedra::GetSurfaceTriangulation,"triangulation of facets (for plotting)")
 			.def("GetSurfaces",&Polyhedra::GetSurfaces,"get indices of surfaces' vertices (for postprocessing)")
-			.def("setVertices",&Polyhedra::setVertices,"set vertices and update receiver")
-		);		
+			.def("setVertices",&Polyhedra::setVertices,"set vertices and update receiver. Takes a list/tuple of vertices as argument.\n\n.. note:: Causes memory leaks, so if you want to use it maaaany times, use one of setVertices mentioned lower, passing each vertex as individual argument (currently only setVertices(v1,v2,v3,v4) for tetrahedron is implemented, on request it is easy to implement more vertices).")
+			.def("setVertices",&Polyhedra::setVertices4,"set 4 vertices and update receiver. Each vertex is single argument.")
+		);
 		REGISTER_CLASS_INDEX(Polyhedra,Shape);
 };
 REGISTER_SERIALIZABLE(Polyhedra);
@@ -150,7 +155,9 @@ class Bo1_Polyhedra_Aabb: public BoundFunctor{
 	public:
 		void go(const shared_ptr<Shape>& ig, shared_ptr<Bound>& bv, const Se3r& se3, const Body*);
 		FUNCTOR1D(Polyhedra);
-		YADE_CLASS_BASE_DOC(Bo1_Polyhedra_Aabb,BoundFunctor,"Create/update :yref:`Aabb` of a :yref:`Polyhedra`");
+		YADE_CLASS_BASE_DOC_ATTRS(Bo1_Polyhedra_Aabb,BoundFunctor,"Create/update :yref:`Aabb` of a :yref:`Polyhedra`",
+			((Real,aabbEnlargeFactor,((void)"deactivated",-1),,"see :yref:`Bo1_Sphere_Aabb.aabbEnlargeFactor`"))
+		);
 };
 REGISTER_SERIALIZABLE(Bo1_Polyhedra_Aabb);
 
@@ -318,8 +325,6 @@ void PrintPolyhedron(Polyhedron P);
 void PrintPolyhedron2File(Polyhedron P,FILE* X);
 //normal by least square fitting of separating segments
 Vector3r FindNormal(Polyhedron Int, Polyhedron PA, Polyhedron PB);
-//calculate area of projection of polyhedron into the plane
-Real CalculateProjectionArea(Polyhedron Int, CGALvector CGALnormal);
 //split polyhedron
 shared_ptr<Body> SplitPolyhedra(const shared_ptr<Body>& body, Vector3r direction, Vector3r point);
 //new polyhedra
