@@ -2,24 +2,31 @@
 // https://www.vutbr.cz/www_base/gigadisk.php?i=95194aa9a
 
 #ifdef YADE_CGAL
+// NDEBUG causes crashes in CGAL sometimes. Anton
+#ifdef NDEBUG
+	#undef NDEBUG
+#endif
+#include "Polyhedra_Ig2.hpp"
 
-#include"Polyhedra.hpp"
-#include"Polyhedra_Ig2.hpp"
-#include<pkg/dem/ScGeom.hpp>
-
-#define _USE_MATH_DEFINES
-
-YADE_PLUGIN(/* self-contained in hpp: */ (Ig2_Polyhedra_Polyhedra_PolyhedraGeom) (Ig2_Wall_Polyhedra_PolyhedraGeom) (Ig2_Facet_Polyhedra_PolyhedraGeom) (Ig2_Sphere_Polyhedra_ScGeom) );
+YADE_PLUGIN(/* self-contained in hpp: */ (Ig2_Polyhedra_Polyhedra_PolyhedraGeom) (Ig2_Wall_Polyhedra_PolyhedraGeom) (Ig2_Facet_Polyhedra_PolyhedraGeom) (Ig2_Sphere_Polyhedra_ScGeom) 
+	(Ig2_Polyhedra_Polyhedra_ScGeom) (Ig2_Polyhedra_Polyhedra_PolyhedraGeomOrScGeom)
+);
 
 //**********************************************************************************
 /*! Create Polyhedra (collision geometry) from colliding Polyhedras. */
 
-bool Ig2_Polyhedra_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const shared_ptr<Shape>& shape2,const State& state1,const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& interaction){
-
+bool Ig2_Polyhedra_Polyhedra_PolyhedraGeom::go(
+		const shared_ptr<Shape>& shape1,
+		const shared_ptr<Shape>& shape2,
+		const State& state1,
+		const State& state2,
+		const Vector3r& shift2,
+		const bool& force,
+		const shared_ptr<Interaction>& interaction) {
 	//get polyhedras
 	const Se3r& se31=state1.se3; 
 	const Se3r& se32=state2.se3;
-	Polyhedra* A = static_cast<Polyhedra*>(shape1.get());		
+	Polyhedra* A = static_cast<Polyhedra*>(shape1.get());
 	Polyhedra* B = static_cast<Polyhedra*>(shape2.get());
 
 	bool isNew = !interaction->geom;
@@ -27,65 +34,85 @@ bool Ig2_Polyhedra_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,c
 	//move and rotate 1st the CGAL structure Polyhedron
 	Matrix3r rot_mat = (se31.orientation).toRotationMatrix();
 	Vector3r trans_vec = se31.position;
-	Transformation t_rot_trans(rot_mat(0,0),rot_mat(0,1),rot_mat(0,2), trans_vec[0],rot_mat(1,0),rot_mat(1,1),rot_mat(1,2),trans_vec[1],rot_mat(2,0),rot_mat(2,1),rot_mat(2,2),trans_vec[2],1.);
+	const Real& s = interactionDetectionFactor;
+	
+	Transformation t_rot_trans(
+		s*rot_mat(0,0), s*rot_mat(0,1), s*rot_mat(0,2), trans_vec[0],
+		s*rot_mat(1,0), s*rot_mat(1,1), s*rot_mat(1,2), trans_vec[1],
+		s*rot_mat(2,0), s*rot_mat(2,1), s*rot_mat(2,2), trans_vec[2],
+		1.
+	);
+	
 	Polyhedron PA = A->GetPolyhedron();
 	std::transform( PA.points_begin(), PA.points_end(), PA.points_begin(), t_rot_trans);
+	
 	std::transform( PA.facets_begin(), PA.facets_end(), PA.planes_begin(),Plane_equation());	
-
-
+	
 	//move and rotate 2nd the CGAL structure Polyhedron
 	rot_mat = (se32.orientation).toRotationMatrix();
 	trans_vec = se32.position + shift2;
-	t_rot_trans = Transformation(rot_mat(0,0),rot_mat(0,1),rot_mat(0,2), trans_vec[0],rot_mat(1,0),rot_mat(1,1),rot_mat(1,2),trans_vec[1],rot_mat(2,0),rot_mat(2,1),rot_mat(2,2),trans_vec[2],1.);
+	t_rot_trans = Transformation(
+		s*rot_mat(0,0), s*rot_mat(0,1), s*rot_mat(0,2), trans_vec[0],
+		s*rot_mat(1,0), s*rot_mat(1,1), s*rot_mat(1,2), trans_vec[1],
+		s*rot_mat(2,0), s*rot_mat(2,1), s*rot_mat(2,2), trans_vec[2],
+		1.
+	);
+	
 	Polyhedron PB = B->GetPolyhedron();
+	
 	std::transform( PB.points_begin(), PB.points_end(), PB.points_begin(), t_rot_trans);
 	std::transform( PB.facets_begin(), PB.facets_end(), PB.planes_begin(),Plane_equation());
-
+	
 	shared_ptr<PolyhedraGeom> bang;
+	
 	if (isNew) {
 		// new interaction
 		bang=shared_ptr<PolyhedraGeom>(new PolyhedraGeom());
 		bang->sep_plane.assign(3,0);
 		bang->contactPoint = Vector3r(0,0,0);
 		bang->isShearNew = true;
-		interaction->geom = bang;
 	}else{	
 		// use data from old interaction
-  		bang=YADE_PTR_CAST<PolyhedraGeom>(interaction->geom);
+		bang=YADE_PTR_CAST<PolyhedraGeom>(interaction->geom);
 		bang->isShearNew = bang->equivalentPenetrationDepth<=0;
 	}
-
-
+  
 	//find intersection Polyhedra
 	Polyhedron Int;
 	Int = Polyhedron_Polyhedron_intersection(PA,PB,ToCGALPoint(bang->contactPoint),ToCGALPoint(se31.position),ToCGALPoint(se32.position+shift2), bang->sep_plane);	
-
+	
 	//volume and centroid of intersection
 	Real volume;
 	Vector3r centroid;	
 	P_volume_centroid(Int, &volume, &centroid);
- 	if(isnan(volume) || volume<=1E-25 || volume > min(A->GetVolume(),B->GetVolume())) {
+	
+ 	if(std::isnan(volume) || volume<=1E-25 || volume > min(A->GetVolume(),B->GetVolume())) {
 		bang->equivalentPenetrationDepth=0;
 		bang->penetrationVolume=min(A->GetVolume(),B->GetVolume());
 		bang->normal = (A->GetVolume()>B->GetVolume() ? 1 : -1)*(se32.position+shift2-se31.position);
-		return true;
+		return !isNew;
 	}
-	if ( (!Is_inside_Polyhedron(PA, ToCGALPoint(centroid))) or (!Is_inside_Polyhedron(PB, ToCGALPoint(centroid))))  {bang->equivalentPenetrationDepth=0; return true;}
+	
+	if ((!Is_inside_Polyhedron(PA, ToCGALPoint(centroid))) or 
+			(!Is_inside_Polyhedron(PB, ToCGALPoint(centroid)))) {
+				bang->equivalentPenetrationDepth=0;
+				return !isNew;
+		}
 
+	if (isNew) interaction->geom = bang;
+	
 	//find normal direction
-        Vector3r normal = FindNormal(Int, PA, PB);
+	Vector3r normal = FindNormal(Int, PA, PB);
+	
 	if((se32.position+shift2-centroid).dot(normal)<0) normal*=-1;	
-
-	//calculate area of projection of Intersection into the normal plane
-	//Real area = CalculateProjectionArea(Int, ToCGALVector(normal));
-	//if(isnan(area) || area<=1E-20) {bang->equivalentPenetrationDepth=0; return true;}
-        //Real area = volume/1E-8;
-        Real area = std::pow(volume,2./3.);
+	
+	Real area = std::pow(volume,2./3.);
 	// store calculated stuff in bang; some is redundant
 	bang->equivalentCrossSection=area;
 	bang->contactPoint=centroid;
 	bang->penetrationVolume=volume;
 	bang->equivalentPenetrationDepth=volume/area;
+	scene = Omega::instance().getScene().get();
 	bang->precompute(state1,state2,scene,interaction,normal,bang->isShearNew,shift2);
 	bang->normal=normal;
 	
@@ -99,14 +126,27 @@ bool Ig2_Polyhedra_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,c
 	PrintPolyhedron2File(Int,fin);
 	fclose(fin);
 	*/
-	return true;	
+	return true;
 }
 
 //**********************************************************************************
+
+bool Ig2_Polyhedra_Polyhedra_PolyhedraGeom::goReverse(
+		const shared_ptr<Shape>& shape1,
+		const shared_ptr<Shape>& shape2,
+		const State& state1,
+		const State& state2,
+		const Vector3r& shift2,
+		const bool& force,
+		const shared_ptr<Interaction>& c) {
+			return go(shape1,shape2,state2,state1,-shift2,force,c);
+		}
+//**********************************************************************************
 /*! Create Polyhedra (collision geometry) from colliding Polyhedron and Wall. */
 
-bool Ig2_Wall_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const shared_ptr<Shape>& shape2,const State& state1,const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& interaction){
-
+bool Ig2_Wall_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const shared_ptr<Shape>& shape2,
+		const State& state1,const State& state2, const Vector3r& shift2, const bool& force,
+		const shared_ptr<Interaction>& interaction) {
 	const int& PA(shape1->cast<Wall>().axis); 
 	const int& sense(shape1->cast<Wall>().sense);
 	const Se3r& se31=state1.se3; const Se3r& se32=state2.se3;	
@@ -117,7 +157,11 @@ bool Ig2_Wall_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const
 	//move and rotate also the CGAL structure Polyhedron
 	Matrix3r rot_mat = (se32.orientation).toRotationMatrix();
 	Vector3r trans_vec = se32.position;
-	Transformation t_rot_trans(rot_mat(0,0),rot_mat(0,1),rot_mat(0,2), trans_vec[0],rot_mat(1,0),rot_mat(1,1),rot_mat(1,2),trans_vec[1],rot_mat(2,0),rot_mat(2,1),rot_mat(2,2),trans_vec[2],1.);
+	
+	Transformation t_rot_trans(
+		rot_mat(0,0),rot_mat(0,1),rot_mat(0,2),trans_vec[0],
+		rot_mat(1,0),rot_mat(1,1),rot_mat(1,2),trans_vec[1],
+		rot_mat(2,0),rot_mat(2,1),rot_mat(2,2),trans_vec[2],1.);
 	Polyhedron PB = B->GetPolyhedron();
 	std::transform( PB.points_begin(), PB.points_end(), PB.points_begin(), t_rot_trans);
 	std::transform( PB.facets_begin(), PB.facets_end(), PB.planes_begin(),Plane_equation());
@@ -132,7 +176,7 @@ bool Ig2_Wall_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const
 		if (dot<1) { normal[PA] = -1; }
 	}
 	CGALvector CGALnormal = CGALvector(normal[0],normal[1],normal[2]);
-        Plane A = Plane(CGALpoint(se31.position[0],se31.position[1],se31.position[2]),CGALvector(normal[0],normal[1],normal[2]));
+	Plane A = Plane(CGALpoint(se31.position[0],se31.position[1],se31.position[2]),CGALvector(normal[0],normal[1],normal[2]));
 
 	shared_ptr<PolyhedraGeom> bang;
 	if (isNew) {
@@ -141,9 +185,9 @@ bool Ig2_Wall_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const
 		bang->contactPoint = Vector3r(0,0,0);
 		bang->isShearNew = true;
 		interaction->geom = bang;
-	}else{	
+	}else{
 		// use data from old interaction
-  		bang=YADE_PTR_CAST<PolyhedraGeom>(interaction->geom);
+		bang=YADE_PTR_CAST<PolyhedraGeom>(interaction->geom);
 		bang->isShearNew = bang->equivalentPenetrationDepth<=0;
 	}
 
@@ -153,15 +197,13 @@ bool Ig2_Wall_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const
 
 	//volume and centroid of intersection
 	Real volume;
-	Vector3r centroid;	
+	Vector3r centroid;
 	P_volume_centroid(Int, &volume, &centroid);
-	if(isnan(volume) || volume<=1E-25 || volume > B->GetVolume())  {bang->equivalentPenetrationDepth=0; return true;}
+	if(std::isnan(volume) || volume<=1E-25 || volume > B->GetVolume())  {bang->equivalentPenetrationDepth=0; return true;}
 	if (!Is_inside_Polyhedron(PB, ToCGALPoint(centroid)))  {bang->equivalentPenetrationDepth=0; return true;}
 
 	//calculate area of projection of Intersection into the normal plane
-        Real area = volume/1E-8;
-	//Real area = CalculateProjectionArea(Int, CGALnormal);
-	//if(isnan(area) || area<=1E-20) {bang->equivalentPenetrationDepth=0; return true;}
+	Real area = volume/1E-8;
 
 	// store calculated stuff in bang; some is redundant
 	bang->equivalentCrossSection=area;
@@ -177,29 +219,34 @@ bool Ig2_Wall_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const
 //**********************************************************************************
 /*! Create Polyhedra (collision geometry) from colliding Polyhedron and Facet. */
 
-bool Ig2_Facet_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const shared_ptr<Shape>& shape2,const State& state1,const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& interaction){
-
-
+bool Ig2_Facet_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const shared_ptr<Shape>& shape2,
+																					 const State& state1,const State& state2,
+																					 const Vector3r& shift2, const bool& force,
+																					 const shared_ptr<Interaction>& interaction){
+	
 	const Se3r& se31=state1.se3; 
 	const Se3r& se32=state2.se3;
 	Facet*   A = static_cast<Facet*>(shape1.get());	
 	Polyhedra* B = static_cast<Polyhedra*>(shape2.get());
-
+	
 	bool isNew = !interaction->geom;
-
+	
 	//move and rotate 1st the CGAL structure Polyhedron
 	Matrix3r rot_mat = (se32.orientation).toRotationMatrix();
 	Vector3r trans_vec = se32.position;
-	Transformation t_rot_trans(rot_mat(0,0),rot_mat(0,1),rot_mat(0,2), trans_vec[0],rot_mat(1,0),rot_mat(1,1),rot_mat(1,2),trans_vec[1],rot_mat(2,0),rot_mat(2,1),rot_mat(2,2),trans_vec[2],1.);
+	Transformation t_rot_trans(
+		rot_mat(0,0),rot_mat(0,1),rot_mat(0,2),trans_vec[0],
+		rot_mat(1,0),rot_mat(1,1),rot_mat(1,2),trans_vec[1],
+		rot_mat(2,0),rot_mat(2,1),rot_mat(2,2),trans_vec[2],1.);
 	Polyhedron PB = B->GetPolyhedron();
 	std::transform( PB.points_begin(), PB.points_end(), PB.points_begin(), t_rot_trans);
 	std::transform( PB.facets_begin(), PB.facets_end(), PB.planes_begin(),Plane_equation());
-
+	
 	//move and rotate facet
 	vector<CGALpoint> v;
 	v.resize(6);
 	for (int i=0; i<3; i++) v[i] = ToCGALPoint(se31.orientation*A->vertices[i] + se31.position); // vertices in global coordinates
-
+	
 	//determine 
 	CGALpoint f_center((v[0].x()+v[1].x()+v[2].x())/3.,(v[0].y()+v[1].y()+v[2].y())/3.,(v[0].z()+v[1].z()+v[2].z())/3.);
 	CGALvector f_normal = CGAL::cross_product((v[1]-v[0]),(v[2]-v[0]));
@@ -207,27 +254,25 @@ bool Ig2_Facet_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const
 	//chage normal + change order of vertices to get outwarding facet normal for initial tetrahedron
  	if ((ToCGALPoint(se32.position)-f_center)*(f_normal) < 0) {
 		f_normal = (-1)*f_normal;
-  		CGALpoint help;
+		CGALpoint help;
 		help = v[0];
 		v[0]=v[1];
-		v[1]=help;	
+		v[1]=help;
 	}
-
+	
 	Real f_area = sqrt(f_normal.squared_length());
 	for (int i=3; i<6; i++) v[i] = v[i-3]-f_normal/f_area*0.05*sqrt(f_area); // vertices in global coordinates
 
 	Polyhedron PA;
-	//use convex hull	
-	//CGAL::convex_hull_3(v.begin(), v.end(), PA);
 
 	//construct polyhedron directly
 	Polyhedron::Halfedge_iterator hei = PA.make_tetrahedron(v[4],v[1],v[0],v[2]);
 	hei = PA.split_vertex(hei, hei->next()->opposite());
-	hei->vertex()->point() = v[3];	
+	hei->vertex()->point() = v[3];
 	hei = PA.split_facet(hei->next()->next()->next(),hei->next());
 	hei = PA.split_vertex(hei, hei->next_on_vertex()->next_on_vertex());
-	hei->vertex()->point() = v[5];		
-
+	hei->vertex()->point() = v[5];
+	
 	shared_ptr<PolyhedraGeom> bang;
 	if (isNew) {
 		// new interaction
@@ -236,32 +281,30 @@ bool Ig2_Facet_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const
 		bang->contactPoint = Vector3r(0,0,0);
 		bang->isShearNew = true;
 		interaction->geom = bang;
-	}else{	
+	} else {
 		// use data from old interaction
-  		bang=YADE_PTR_CAST<PolyhedraGeom>(interaction->geom);
+		bang=YADE_PTR_CAST<PolyhedraGeom>(interaction->geom);
 		bang->isShearNew = bang->equivalentPenetrationDepth<=0;
 	}
-
+	
 	//find intersection Polyhedra
 	Polyhedron Int;
 	Int = Polyhedron_Polyhedron_intersection(PA,PB,ToCGALPoint(bang->contactPoint),ToCGALPoint(se31.position),ToCGALPoint(se32.position), bang->sep_plane);	
-
+	
 	//volume and centroid of intersection
 	Real volume;
-	Vector3r centroid;	
+	Vector3r centroid;
 	P_volume_centroid(Int, &volume, &centroid);
- 	if(isnan(volume) || volume<=1E-25 || volume > B->GetVolume()) {bang->equivalentPenetrationDepth=0; return true;}
+	if(std::isnan(volume) || volume<=1E-25 || volume > B->GetVolume()) {bang->equivalentPenetrationDepth=0; return true;}
 	if (!Is_inside_Polyhedron(PB, ToCGALPoint(centroid)))  {bang->equivalentPenetrationDepth=0; return true;}
-
+	
 	//find normal direction
 	Vector3r normal = FindNormal(Int, PA, PB);
 	if((se32.position-centroid).dot(normal)<0) normal*=-1;
-
+	
 	//calculate area of projection of Intersection into the normal plane
-        Real area = volume/1E-8;
-	//Real area = CalculateProjectionArea(Int, ToCGALVector(normal));
-	//if(isnan(area) || area<=1E-20) {bang->equivalentPenetrationDepth=0; return true;}
-		
+	Real area = volume/1E-8;
+	
 	// store calculated stuff in bang; some is redundant
 	bang->equivalentCrossSection=area;
 	bang->contactPoint=centroid;
@@ -269,8 +312,8 @@ bool Ig2_Facet_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const
 	bang->equivalentPenetrationDepth=volume/area;
 	bang->precompute(state1,state2,scene,interaction,normal,bang->isShearNew,shift2);
 	bang->normal=normal;
-
-	return true;	
+	
+	return true;
 }
 
 //**********************************************************************************
@@ -399,58 +442,76 @@ bool Ig2_Sphere_Polyhedra_ScGeom::go(const shared_ptr<Shape>& shape1,const share
 	return true;
 }
 
-/*
-bool Ig2_Sphere_Polyhedra_PolyhedraGeom::go(const shared_ptr<Shape>& shape1,const shared_ptr<Shape>& shape2,const State& state1,const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& interaction){
 
-	const Se3r& se31=state1.se3; 
+
+//**********************************************************************************
+/*! Plyhedra -> ScGeom. */
+bool Ig2_Polyhedra_Polyhedra_ScGeom::go(const shared_ptr<Shape>& shape1, const shared_ptr<Shape>& shape2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& interaction) {
+	const Se3r& se31=state1.se3;
 	const Se3r& se32=state2.se3;
-	Polyhedra* B = static_cast<Polyhedra*>(shape2.get());
-	const Real& r=shape1->cast<Sphere>().radius;
-
-	//cout << "Sphere x Polyhedra" << endl;
-
+	shared_ptr<ScGeom> geom;
 	bool isNew = !interaction->geom;
-
-	//move and rotate 1st the CGAL structure Polyhedron
-	Matrix3r rot_mat = (se32.orientation).toRotationMatrix();
-	Vector3r trans_vec = se32.position;
-	Transformation t_rot_trans(rot_mat(0,0),rot_mat(0,1),rot_mat(0,2), trans_vec[0],rot_mat(1,0),rot_mat(1,1),rot_mat(1,2),trans_vec[1],rot_mat(2,0),rot_mat(2,1),rot_mat(2,2),trans_vec[2],1.);
-	Polyhedron PB = B->GetPolyhedron();
-	std::transform( PB.points_begin(), PB.points_end(), PB.points_begin(), t_rot_trans);
-	std::transform( PB.facets_begin(), PB.facets_end(), PB.planes_begin(),Plane_equation());	
-	
-	shared_ptr<PolyhedraGeom> bang;
 	if (isNew) {
-		// new interaction
-		bang=shared_ptr<PolyhedraGeom>(new PolyhedraGeom());
-		bang->isShearNew = true;
-		interaction->geom = bang;
-	}else{	
-		// use data from old interaction
-  		bang=YADE_PTR_CAST<PolyhedraGeom>(interaction->geom);
+		Ig2_Polyhedra_Polyhedra_PolyhedraGeom ppGeom = Ig2_Polyhedra_Polyhedra_PolyhedraGeom();
+		ppGeom.interactionDetectionFactor = interactionDetectionFactor;
+		bool pp = ppGeom.go(shape1,shape2,state2,state1,shift2,force,interaction);
+		if (!pp) {
+			return false;
+		}
+		shared_ptr<PolyhedraGeom> pGeom = YADE_PTR_CAST<PolyhedraGeom>(interaction->geom);	
+		geom = shared_ptr<ScGeom>(new ScGeom());
+		geom->radius1 = (pGeom->contactPoint-se31.position).norm();
+		geom->radius2 = (pGeom->contactPoint-se32.position+shift2).norm();
+		interaction->geom=geom;
+	} else {
+		geom = YADE_PTR_CAST<ScGeom>(interaction->geom);
 	}
-
-	//volume and centroid of intersection
-	Real volume, area;
-        CGALvector normalCGAL;
-	CGALpoint centroidCGAL=ToCGALPoint(se32.position);
-	Sphere_Polyhedron_intersection(PB, r, ToCGALPoint(se31.position), centroidCGAL,  volume, normalCGAL, area);
- 	if(isnan(volume) || volume<=1E-25 || volume > B->GetVolume()) {bang->equivalentPenetrationDepth=0; return true;}
-	Vector3r centroid = FromCGALPoint(centroidCGAL);
-	Vector3r normal = FromCGALVector(normalCGAL);
-
-	
-
-	// store calculated stuff in bang; some is redundant
-	bang->equivalentCrossSection=area;
-	bang->contactPoint=centroid;
-	bang->penetrationVolume=volume;
-	bang->equivalentPenetrationDepth=volume/area;
-	bang->precompute(state1,state2,scene,interaction,normal,bang->isShearNew,shift2);
-	bang->normal=normal;
-
-	return true;	
+	const Real& radius1 = geom->radius1;
+	const Real& radius2 = geom->radius2;
+	Vector3r normal=(se32.position+shift2)-se31.position;
+	Real norm=normal.norm(); normal/=norm; // normal is unit vector now
+	Real penetrationDepth=radius1+radius2-norm;
+	geom->contactPoint=se31.position+(radius1-0.5*penetrationDepth)*normal;//0.5*(pt1+pt2);
+	geom->penetrationDepth=penetrationDepth;
+	scene = Omega::instance().getScene().get();
+	geom->precompute(state1,state2,scene,interaction,normal,isNew,shift2,false);
+	return true;
 }
-*/
+
+bool Ig2_Polyhedra_Polyhedra_ScGeom::goReverse(const shared_ptr<Shape>& shape1, const shared_ptr<Shape>& shape2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& interaction) {
+	return go(shape1,shape2,state2,state1,-shift2,force,interaction);
+}
+
+
+
+
+bool Ig2_Polyhedra_Polyhedra_PolyhedraGeomOrScGeom::go(const shared_ptr<Shape>& shape1, const shared_ptr<Shape>& shape2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& interaction) {
+	bool isNew = !interaction->geom;
+	if (isNew) {
+		if (createScGeom) {
+			return ig2scGeom->go(shape1,shape2,state1,state2,shift2,force,interaction);
+		} else {
+			return ig2polyhedraGeom->go(shape1,shape2,state1,state2,shift2,force,interaction);
+		}
+	}
+	//
+	ScGeom* scGeom = dynamic_cast<ScGeom*>(interaction->geom.get());
+	if (scGeom) {
+		return ig2scGeom->go(shape1,shape2,state1,state2,shift2,force,interaction);
+	}
+	//
+	PolyhedraGeom* pGeom = dynamic_cast<PolyhedraGeom*>(interaction->geom.get());
+	if (pGeom) {
+		return ig2polyhedraGeom->go(shape1,shape2,state1,state2,shift2,force,interaction);
+	}
+	//
+	LOG_ERROR("TODO, should not happen");
+	return false;
+}
+
+bool Ig2_Polyhedra_Polyhedra_PolyhedraGeomOrScGeom::goReverse(const shared_ptr<Shape>& shape1, const shared_ptr<Shape>& shape2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& interaction) {
+	return go(shape1,shape2,state2,state1,-shift2,force,interaction);
+}
+
 
 #endif // YADE_CGAL
