@@ -132,9 +132,9 @@ class Shop{
 		//! (contribution of normal and shear forces)
 		static py::tuple normalShearStressTensors(bool compressionPositive=false, bool splitNormalTensor=false, Real thresholdForce=NaN);
 		
-		//! Function to compute fabric tensor of periodic cell
-		static void fabricTensor(Real& Fmean, Matrix3r& fabric, Matrix3r& fabricStrong, Matrix3r& fabricWeak, bool splitTensor=false, bool revertSign=false, Real thresholdForce=NaN);
-		static py::tuple fabricTensor(bool splitTensor=false, bool revertSign=false, Real thresholdForce=NaN);
+		//! Function to compute fabric tensor
+		static void fabricTensor(Real& Fmean, Matrix3r& fabric, Matrix3r& fabricStrong, Matrix3r& fabricWeak, Real cutoff=0.0, bool splitTensor=false, Real thresholdForce=NaN);
+		static py::tuple fabricTensor(Real cutoff=0.0, bool splitTensor=false, Real thresholdForce=NaN);
 		
 		//! Function to set translational and rotational velocities of all bodies to zero
 		static void calm(const shared_ptr<Scene>& rb=shared_ptr<Scene>(), int mask=-1);
