@@ -42,6 +42,7 @@
 	#include"pkg/common/Gl1_NormPhys.hpp"
 #endif
 
+#include <boost/filesystem.hpp>
 #include "py/_utils.hpp"
 
 
@@ -83,8 +84,6 @@ Matrix3r Shop::flipCell(const Matrix3r& _flip){
 		if(flip(i,j)!=double(int(flip(i,j)))) LOG_WARN("Flip matrix entry "<<flip(i,j)<<" at ["<<i<<","<<j<<"] not integer?! (will be rounded)");
 		trsfInc(i,j)=int(flip(i,j))*size[j]/size[i];
 	}
-	TRWM3MAT(cell->trsf);
-	TRWM3MAT(trsfInc);
 	cell->trsf+=trsfInc;
 	cell->postLoad(*cell);
 
@@ -306,7 +305,7 @@ Real Shop::getSpheresVolume(const shared_ptr<Scene>& _scene, int mask){
 	const shared_ptr<Scene> scene=(_scene?_scene:Omega::instance().getScene());
 	Real vol=0;
 	FOREACH(shared_ptr<Body> b, *scene->bodies){
-		if (!b || !b->isDynamic()) continue;
+		if (!b) continue;
 		Sphere* s=dynamic_cast<Sphere*>(b->shape.get());
 		if((!s) or ((mask>0) and ((b->groupMask & mask)==0))) continue;
 		vol += (4/3.)*Mathr::PI*pow(s->radius,3);
@@ -318,7 +317,7 @@ Real Shop::getSpheresMass(const shared_ptr<Scene>& _scene, int mask){
 	const shared_ptr<Scene> scene=(_scene?_scene:Omega::instance().getScene());
 	Real mass=0;
 	FOREACH(shared_ptr<Body> b, *scene->bodies){
-		if (!b || !b->isDynamic()) continue;
+		if (!b) continue;
 		Sphere* s=dynamic_cast<Sphere*>(b->shape.get());
 		if((!s) or ((mask>0) and ((b->groupMask & mask)==0))) continue;
 		mass += b->state->mass;
