@@ -39,6 +39,7 @@
 
 #include <core/Timing.hpp>
 #include <lib/serialization/ObjectIO.hpp>
+#include <csignal>
 
 namespace py = boost::python;
 
@@ -120,6 +121,52 @@ class pyBodyContainer{
 			}
 		}
 	}
+	void deleteClumpMember(shared_ptr<Body> clumpBody, shared_ptr<Body> memberBody){  //FIXME
+		const shared_ptr<Clump> clump(YADE_PTR_CAST<Clump>(clumpBody->shape));
+		if (clump->members.size()==1 ){
+			Clump::del(clumpBody,memberBody); //phD was not commented out
+			for (int i=0; i<clump->ids.size(); i++){
+				if (clump->ids[i] == memberBody->getId()){
+					clump->ids.erase(clump->ids.begin()+i);
+				}
+			}
+			proxee->erase(memberBody->getId(),false);
+			proxee->erase(clumpBody->getId(),false);
+			
+		}else{
+			Clump::del(clumpBody,memberBody); //pHD was not commented out
+			for (int i=0; i<clump->ids.size(); i++){
+				if (clump->ids[i] == memberBody->getId()){
+					clump->ids.erase(clump->ids.begin()+i);
+				}
+			}
+			Clump::updatePropertiesNonSpherical(clumpBody,/*intersecting*/ false);
+			proxee->erase(memberBody->getId(),false);
+			
+		}
+		
+	}
+	void deleteClumpBody(shared_ptr<Body> clumpBody){ //FIXME
+		const shared_ptr<Clump> clump(YADE_PTR_CAST<Clump>(clumpBody->shape));
+
+		//if (clump->members.size()==0 ){
+		//	proxee->erase(clumpBody->getId());
+		//}else{
+			Scene* scene(Omega::instance().getScene().get());
+			int totalNumber = clump->ids.size();
+			int count = 0;
+			while(count<totalNumber){
+			//for (int i=0; i<clump->ids.size(); i++){
+				shared_ptr<Body> memberBody (YADE_PTR_CAST<Body>( Body::byId(clump->ids[/*i */0],scene) ));
+				deleteClumpMember(clumpBody,memberBody);
+				//clump->ids.erase(clump->ids.begin()+i);
+				//proxee->erase(memberBody->getId());
+				count++;			
+			}
+
+			proxee->erase(clumpBody->getId(),true);
+		//}
+	}
 	void addToClump(vector<Body::id_t> bids, Body::id_t cid, unsigned int discretization){
 		Scene* scene(Omega::instance().getScene().get());	// get scene
 		shared_ptr<Body> clp = Body::byId(cid,scene);		// get clump pointer
@@ -835,6 +882,8 @@ BOOST_PYTHON_MODULE(wrapper)
 		.def("appendClumped",&pyBodyContainer::appendClump,(py::arg("discretization")=0),"Append given list of bodies as a clump (rigid aggregate); returns a tuple of ``(clumpId,[memberId1,memberId2,...])``. Clump masses and inertia are adapted automatically (for details see :yref:`clump()<BodyContainer.clump>`).")
 		.def("clump",&pyBodyContainer::clump,(py::arg("discretization")=0),"Clump given bodies together (creating a rigid aggregate); returns ``clumpId``. Clump masses and inertia are adapted automatically when discretization>0. If clump members are overlapping this is done by integration/summation over mass points using a regular grid of cells (grid cells length is defined as $R_{min}/discretization$, where $R_{min}$ is minimum clump member radius). For non-overlapping members inertia of the clump is the sum of inertias from members. If discretization<=0 sum of inertias from members is used (faster, but inaccurate).")
 		.def("updateClumpProperties",&pyBodyContainer::updateClumpProperties,(py::arg("excludeList")=py::list(),py::arg("discretization")=5),"Manually force Yade to update clump properties mass, volume and inertia (for details of 'discretization' value see :yref:`clump()<BodyContainer.clump>`). Can be used, when clumps are modified or erased during a simulation. Clumps can be excluded from the calculation by giving a list of ids: *O.bodies.updateProperties([ids])*.")
+		.def("deleteClumpMember", &pyBodyContainer::deleteClumpMember,"Erase clump member.") //FIXME
+		.def("deleteClumpBody", &pyBodyContainer::deleteClumpBody,"Erase clump member.")//FIXME
 		.def("addToClump",&pyBodyContainer::addToClump,(py::arg("discretization")=0),"Add body b (or a list of bodies) to an existing clump c. c must be clump and b may not be a clump member of c. Clump masses and inertia are adapted automatically (for details see :yref:`clump()<BodyContainer.clump>`).\n\nSee :ysrc:`examples/clumps/addToClump-example.py` for an example script.\n\n.. note:: If b is a clump itself, then all members will be added to c and b will be deleted. If b is a clump member of clump d, then all members from d will be added to c and d will be deleted. If you need to add just clump member b, :yref:`release<BodyContainer.releaseFromClump>` this member from d first.")
 		.def("releaseFromClump",&pyBodyContainer::releaseFromClump,(py::arg("discretization")=0),"Release body b from clump c. b must be a clump member of c. Clump masses and inertia are adapted automatically (for details see :yref:`clump()<BodyContainer.clump>`).\n\nSee :ysrc:`examples/clumps/releaseFromClump-example.py` for an example script.\n\n.. note:: If c contains only 2 members b will not be released and a warning will appear. In this case clump c should be :yref:`erased<BodyContainer.erase>`.")
 		.def("replaceByClumps",&pyBodyContainer::replaceByClumps,(py::arg("discretization")=0),"Replace spheres by clumps using a list of clump templates and a list of amounts; returns a list of tuples: ``[(clumpId1,[memberId1,memberId2,...]),(clumpId2,[memberId1,memberId2,...]),...]``. A new clump will have the same volume as the sphere, that was replaced. Clump masses and inertia are adapted automatically (for details see :yref:`clump()<BodyContainer.clump>`). \n\n\t *O.bodies.replaceByClumps( [utils.clumpTemplate([1,1],[.5,.5])] , [.9] ) #will replace 90 % of all standalone spheres by 'dyads'*\n\nSee :ysrc:`examples/clumps/replaceByClumps-example.py` for an example script.")
